| Title: | Data sets for package ``LMERConvenienceFunctions'' |
|---|---|
| Description: | This package contains (1) event-related brain potential data recorded from 10 participants at electrodes Fz, Cz, Pz, and Oz (0--300 ms) in the context of Antoine Tremblay's PhD thesis (Tremblay, 2009); (2) ERP amplitudes at electrode Fz restricted to the 100 to 175 millisecond time window; and (3) plotting data generated from a linear mixed-effects model. |
| Authors: | Antoine Tremblay, Department of Psychology, Dalhousie University |
| Maintainer: | Antoine Tremblay <[email protected]> |
| License: | GPL-2 |
| Version: | 2.0 |
| Built: | 2026-05-16 06:43:14 UTC |
| Source: | https://github.com/cran/LCFdata |
LMERConvenienceFunctions
This package contains (1) event-related brain potential data recorded from 10 participants at electrodes Fz, Cz, Pz, and Oz (0–300 ms) in the context of Antoine Tremblay's PhD thesis (Tremblay, 2009); (2) ERP amplitudes at electrode Fz restricted to the 100 to 175 millisecond time window; and (3) plotting data generated from a linear mixed-effects model.
| Package: | LCFdata |
| Type: | Package |
| Version: | 2.0 |
| Date: | 2011-11-27 |
| License: | GPL-2 |
Antoine Tremblay, Department of Psychology, Dalhousie University
Maintainer: Antoine Tremblay, [email protected]
Tremblay, Antoine. (2009). Processing Advantages of Lexical Bundles: Evidence from Self-paced Reading, Word and Sentence Recall, and Free Recall with Event-related Brain Potential Recordings. Ph.D. Dissertation. University of Alberta, Edmonton, Canada. Available for download at http://www.ualberta.ca/~antoinet/ThesisDraft_10_B.pdf.
Event-related brain potential data recorded from 10 participants at electrodes Fz, Cz, Pz, and Oz (0–300 ms) in the context of Antoine Tremblay's PhD thesis (Tremblay, 2009).
data(eeg)data(eeg)
A data frame with 161880 observations on the following 10 variables.
SubjectSubject identifiers (factor).
ItemItem identifiers (factor).
TimeTime from 100 to 175 milliseconds (numeric).
WMCWorking memory capacity (numeric).
FreqBLog frequency of the second word of a four-word sequence (numeric).
LengthBLength (in number of characters) of the second word of a four-word sequence (numeric).
FzAmplitude in microvolts at electrode Fz (numeric).
CzAmplitude in microvolts at electrode Cz (numeric).
PzAmplitude in microvolts at electrode Pz (numeric).
OzAmplitude in microvolts at electrode Oz (numeric).
Tremblay, Antoine. (2009). Processing Advantages of Lexical Bundles: Evidence from Self-paced Reading, Word and Sentence Recall, and Free Recall with Event-related Brain Potential Recordings. Ph.D. Dissertation. University of Alberta, Edmonton, Canada. Available for download at http://www.ualberta.ca/~antoinet/ThesisDraft_10_B.pdf.
data(erpFz) summary(erpFz)data(erpFz) summary(erpFz)
Event-related brain potential data recorded from 10 participants at electrode Fz (100–175 ms) in the context of Antoine Tremblay's PhD thesis (Tremblay, 2009). The actual raw data was averaged over variables LengthBc and WMCc.
data(erpFz)data(erpFz)
A data frame with 120 observations on the following 3 variables.
LengthBcA numeric vector. The mean-centered length (in number of letters) of the second word of a four-word sequence.
WMCcA numeric vector. The mean-centered working memory capacity of the participants.
AmplitudeA numeric vector. The avereaged amplitude of the recorded ERPs.
Tremblay, Antoine. (2009). Processing Advantages of Lexical Bundles: Evidence from Self-paced Reading, Word and Sentence Recall, and Free Recall with Event-related Brain Potential Recordings. Ph.D. Dissertation. University of Alberta, Edmonton, Canada. Available for download at http://www.ualberta.ca/~antoinet/ThesisDraft_10_B.pdf.
data(erpFz) summary(erpFz)data(erpFz) summary(erpFz)
The model call is: lmer(formula = Amplitude ~ FreqBc * LengthBc * WMCc + (1 | Subject) + (1 | Item) + (0 + WMCc | Item), data = dat)
(see details for more).
The plotting data was generated from this model with function plotLMER3d.fnc.
data(z)data(z)
The format is: num [1:30, 1:10] -1.83 -1.95 -2.07 -2.19 -2.32 ... - attr(*, "dimnames")=List of 2 ..$ : chr [1:30] "-2.88262910798122" "-2.50331876315363" "-2.12400841832605" "-1.74469807349846" ... ..$ : chr [1:10] "-0.1857142855" "-0.1410714285" "-0.0517857144999999" "-0.0428571424999999" ...
The model includes a three-way interaction between WMCc (mean-centered working memory capacity), FreqBc (the frequency of use of the second word of a four-word sequence), and LengthBc (the length in number of letters of the second work of a four-word sequence) in addition to by-subject and by-item random intercepts and by-item random slopes for WMCc.
The data is from:
Tremblay, Antoine. (2009). Processing Advantages of Lexical Bundles: Evidence from Self-paced Reading, Word and Sentence Recall, and Free Recall with Event-related Brain Potential Recordings. Ph.D. Dissertation. University of Alberta, Edmonton, Canada. Available for download at http://www.ualberta.ca/~antoinet/ThesisDraft_10_B.pdf.
The model is from:
Tremblay, Antoine, and Newman, Aaron J. (In Preparation). The Analysis of Event-related Potentials using Linear Mixed-effects Models with Complex Random-effect Structures.
data(z) str(z)data(z) str(z)